"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ContentManager = void 0;
const ifunny_api_types_1 = require("@ifunny/ifunny-api-types");
const CachedManager_1 = require("./CachedManager");
const Content_1 = require("../structures/Content");
const iFunnyError_1 = require("../errors/iFunnyError");
/**
 * Manages content for the Client
 * @extends CachedManager<Content>
 */
class ContentManager extends CachedManager_1.CachedManager {
    /**
     * @param client Client instance
     * @param cacheConfig Config to use for Caching
     */
    constructor(client, cacheConfig) {
        super(client, Content_1.Content, cacheConfig);
    }
    /**
     * Fetches Content by its Id
     * @param id Id of the content
     * @param cached Should we return the Cached item? (Default: `true`)
     * @returns Content
     */
    async fetch(contentOrId, cached = true) {
        try {
            let content = await this.resolve(contentOrId);
            if (content && cached)
                return content;
            const id = this.resolveId(contentOrId);
            const { data } = await this.client.instance.get(`content/${id}`);
            content = new Content_1.Content(this.client, data.data);
            this.cache.set(content.id, content, this.cache.config);
            return content;
        }
        catch (error) {
            if (!iFunnyError_1.iFunnyError.isiFunnyError(error))
                throw error;
            if (error.code === ifunny_api_types_1.IFUNNY_ERRORS.NOT_FOUND) {
                return null;
            }
            else
                throw error;
        }
    }
    /**
     * Mark content as read.
     * @param content Content to mark as read
     * @param from Where the content was marked as read.
     */
    async markAsRead(content, from) {
        const items = Array.isArray(content)
            ? content
                .map((c) => {
                if (typeof c === "string")
                    return c;
                return c.id;
            })
                .join(",")
            : content instanceof Content_1.Content
                ? content.id
                : content;
        const response = await this.client.instance.request({
            method: "PUT",
            url: ifunny_api_types_1.Endpoints.reads(items),
            params: new URLSearchParams({ from: from }),
        });
        return response.data.status == 200;
    }
}
exports.ContentManager = ContentManager;
exports.default = ContentManager;
//# sourceMappingURL=ContentManager.js.map